/******************************************************************************* 
* Copyright (C) 2015 Maxim Integrated Products, Inc., All rights Reserved.
* * This software is protected by copyright laws of the United States and
* of foreign countries. This material may also be protected by patent laws
* and technology transfer regulations of the United States and of foreign
* countries. This software is furnished under a license agreement and/or a
* nondisclosure agreement and may only be used or reproduced in accordance
* with the terms of those agreements. Dissemination of this information to
* any party or parties not specified in the license agreement and/or
* nondisclosure agreement is expressly prohibited.
*
* The above copyright notice and this permission notice shall be included
* in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
* IN NO EVENT SHALL MAXIM INTEGRATED BE LIABLE FOR ANY CLAIM, DAMAGES
* OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
* OTHER DEALINGS IN THE SOFTWARE.
* 
* Except as contained in this notice, the name of Maxim Integrated 
* Products, Inc. shall not be used except as stated in the Maxim Integrated 
* Products, Inc. Branding Policy.
*
* The mere transfer of this software does not imply any licenses
* of trade secrets, proprietary technology, copyrights, patents,
* trademarks, maskwork rights, or any other form of intellectual
* property whatsoever. Maxim Integrated Products, Inc. retains all 
* ownership rights.
*     Module Name: ECC test application
*     Description: performs ECDSA testing
*        Filename: ecdsatest.c
*          Author: LSL
*        Compiler: gcc
*
 *******************************************************************************
 */

//1.0.0: initial release, copied from genuine ecdsatest.c
#define VERBOSE

#include <stdio.h>
#include <string.h>
#include <ucl_testing_config.h>
#ifdef ECDSA

#include <ucl/ecdsa_generic_api.h>
#include <ucl/bignum_ecdsa_generic_api.h>
#include <ucl/ucl_retdefs.h>
#include <ucl/ucl_types.h>
#include <ucl/ucl_config.h>
#include <ucl/ucl_defs.h>
#include <ucl/ucl_sys.h>
#include <ucl/ucl_hash.h>
#ifdef HASH_SHA256
#include <ucl/ucl_sha256.h>
#endif
#ifdef HASH_SHA384
#include <ucl/ucl_sha384.h>
#endif
#ifdef HASH_SHA512
#include <ucl/ucl_sha512.h>
#endif
#include <ucl/ucl_rng.h>

extern ucl_type_curve secp256r1;
extern ucl_type_curve secp192r1;
extern ucl_type_curve secp384r1;
extern ucl_type_curve secp521r1;
extern ucl_type_curve bp256r1;
extern ucl_type_curve bp384r1;
extern ucl_type_curve bp512r1;

// number of iterations of each test
#define LOOP 1000

//function testing KAT and sign+verify cycles, using new API and structures introduced in 2.4.9
int test_ecdsa_curves(void)
{
  //P256R1
  //RFC4754 test vector -sha256
  //secret key
  u8 d3_p256r1[]={0xDC,0x51,0xD3,0x86,0x6A,0x15,0xBA,0xCD,0xE3,0x3D,0x96,0xF9,0x92,0xFC,0xA9,0x9D,0xA7,0xE6,0xEF,0x09,0x34,0xE7,0x09,0x75,0x59,0xC2,0x7F,0x16,0x14,0xC8,0x8A,0x7F};
  //message
  //u8 msg3_p256r1[]={'a','b','c'};
  //public key
  u8 xq3_p256r1[]={0x24,0x42,0xA5,0xCC,0x0E,0xCD,0x01,0x5F,0xA3,0xCA,0x31,0xDC,0x8E,0x2B,0xBC,0x70,0xBF,0x42,0xD6,0x0C,0xBC,0xA2,0x00,0x85,0xE0,0x82,0x2C,0xB0,0x42,0x35,0xE9,0x70};
  u8 yq3_p256r1[]={0x6F,0xC9,0x8B,0xD7,0xE5,0x02,0x11,0xA4,0xA2,0x71,0x02,0xFA,0x35,0x49,0xDF,0x79,0xEB,0xCB,0x4B,0xF2,0x46,0xB8,0x09,0x45,0xCD,0xDF,0xE7,0xD5,0x09,0xBB,0xFD,0x7D};
  //signature for the message above
  //  u8 r3_p256r1[]={0xCB,0x28,0xE0,0x99,0x9B,0x9C,0x77,0x15,0xFD,0x0A,0x80,0xD8,0xE4,0x7A,0x77,0x07,0x97,0x16,0xCB,0xBF,0x91,0x7D,0xD7,0x2E,0x97,0x56,0x6E,0xA1,0xC0,0x66,0x95,0x7C};
  //u8 s3_p256r1[]={0x86,0xFA,0x3B,0xB4,0xE2,0x6C,0xAD,0x5B,0xF9,0x0B,0x7F,0x81,0x89,0x92,0x56,0xCE,0x75,0x94,0xBB,0x1E,0xA0,0xC8,0x92,0x12,0x74,0x8B,0xFF,0x3B,0x3D,0x5B,0x03,0x15};

  //KAT for P192
  u8 d3_p192r1[]={0x1a,0x8d,0x59,0x8f,0xc1,0x5b,0xf0,0xfd,0x89,0x03,0x0b,0x5c,0xb1,0x11,0x1a,0xeb,0x92,0xae,0x8b,0xaf,0x5e,0xa4,0x75,0xfb};
  u8 xq3_p192r1[]={0x62,0xB1,0x2D,0x60,0x69,0x0C,0xDC,0xF3,0x30,0xBA,0xBA,0xB6,0xE6,0x97,0x63,0xB4,0x71,0xF9,0x94,0xDD,0x70,0x2D,0x16,0xA5};
  u8 yq3_p192r1[]={0x63,0xBF,0x5E,0xC0,0x80,0x69,0x70,0x5F,0xFF,0xF6,0x5E,0x5C,0xA5,0xC0,0xD6,0x97,0x16,0xDF,0xCB,0x34,0x74,0x37,0x39,0x02};
  //  u8 msg3_p192r1[]={0x00,0x01,0x02,0x03,0x04,0x05,0x06,0x07,0x08,0x09,0x0a,0x0b,0x0c,0x0d,0x0e,0x0f,0x10,0x11,0x12,0x13,0x14,0x15,0x16,0x17};
  //u8 r3_p192r1[]={0x03,0xbe,0x83,0xbb,0x6d,0xff,0x29,0x25,0x87,0xa9,0x4d,0x13,0x8a,0x8e,0x1d,0x0e,0x6f,0x57,0xc3,0x78,0x69,0x68,0xe4,0xa3};
  //u8 s3_p192r1[]={0xa9,0x47,0x0f,0xf0,0xda,0x47,0x7c,0xe6,0x7f,0x44,0x54,0xb1,0xb1,0x28,0x8d,0x04,0x79,0x90,0x6c,0xb6,0xdc,0x04,0x84,0x0d};

  //KAT for P384R1
  //RFC4754 test vector -sha384
  u8 d3_p384r1[] = {0x0B,0xEB,0x64,0x66,0x34,0xBA,0x87,0x73,0x5D,0x77,0xAE,0x48,0x09,0xA0,0xEB,0xEA,0x86,0x55,0x35,0xDE,0x4C,0x1E,0x1D,0xCB,0x69,0x2E,0x84,0x70,0x8E,0x81,0xA5,0xAF,0x62,0xE5,0x28,0xC3,0x8B,0x2A,0x81,0xB3,0x53,0x09,0x66,0x8D,0x73,0x52,0x4D,0x9F};
  //  u8 msg3_p384r1[]={'a','b','c'};
  u8 xq3_p384r1[]={0x96,0x28,0x1B,0xF8,0xDD,0x5E,0x05,0x25,0xCA,0x04,0x9C,0x04,0x8D,0x34,0x5D,0x30,0x82,0x96,0x8D,0x10,0xFE,0xDF,0x5C,0x5A,0xCA,0x0C,0x64,0xE6,0x46,0x5A,0x97,0xEA,0x5C,0xE1,0x0C,0x9D,0xFE,0xC2,0x17,0x97,0x41,0x57,0x10,0x72,0x1F,0x43,0x79,0x22};
  u8 yq3_p384r1[]={0x44,0x76,0x88,0xBA,0x94,0x70,0x8E,0xB6,0xE2,0xE4,0xD5,0x9F,0x6A,0xB6,0xD7,0xED,0xFF,0x93,0x01,0xD2,0x49,0xFE,0x49,0xC3,0x30,0x96,0x65,0x5F,0x5D,0x50,0x2F,0xAD,0x3D,0x38,0x3B,0x91,0xC5,0xE7,0xED,0xAA,0x2B,0x71,0x4C,0xC9,0x9D,0x57,0x43,0xCA};
  //signature for the message above
  //  u8 r3_p384r1[]={0xFB,0x01,0x7B,0x91,0x4E,0x29,0x14,0x94,0x32,0xD8,0xBA,0xC2,0x9A,0x51,0x46,0x40,0xB4,0x6F,0x53,0xDD,0xAB,0x2C,0x69,0x94,0x80,0x84,0xE2,0x93,0x0F,0x1C,0x8F,0x7E,0x08,0xE0,0x7C,0x9C,0x63,0xF2,0xD2,0x1A,0x07,0xDC,0xB5,0x6A,0x6A,0xF5,0x6E,0xB3};
  //  u8 s3_p384r1[]={0xB2,0x63,0xA1,0x30,0x5E,0x05,0x7F,0x98,0x4D,0x38,0x72,0x6A,0x1B,0x46,0x87,0x41,0x09,0xF4,0x17,0xBC,0xA1,0x12,0x67,0x4C,0x52,0x82,0x62,0xA4,0x0A,0x62,0x9A,0xF1,0xCB,0xB9,0xF5,0x16,0xCE,0x0F,0xA7,0xD2,0xFF,0x63,0x08,0x63,0xA0,0x0E,0x8B,0x9F};

  //KAT for P521R1
  //RFC4754 test vector -sha512
  u8 d3_p521r1[] = {0x00,0x65,0xFD,0xA3,0x40,0x94,0x51,0xDC,0xAB,0x0A,0x0E,0xAD,0x45,0x49,0x51,0x12,0xA3,0xD8,0x13,0xC1,0x7B,0xFD,0x34,0xBD,0xF8,0xC1,0x20,0x9D,0x7D,0xF5,0x84,0x91,0x20,0x59,0x77,0x79,0x06,0x0A,0x7F,0xF9,0xD7,0x04,0xAD,0xF7,0x8B,0x57,0x0F,0xFA,0xD6,0xF0,0x62,0xE9,0x5C,0x7E,0x0C,0x5D,0x54,0x81,0xC5,0xB1,0x53,0xB4,0x8B,0x37,0x5F,0xA1};
  //u8 msg3_p521r1[]={'a','b','c'};
 u8 xq3_p521r1[]={0x01,0x51,0x51,0x8F,0x1A,0xF0,0xF5,0x63,0x51,0x7E,0xDD,0x54,0x85,0x19,0x0D,0xF9,0x5A,0x4B,0xF5,0x7B,0x5C,0xBA,0x4C,0xF2,0xA9,0xA3,0xF6,0x47,0x47,0x25,0xA3,0x5F,0x7A,0xFE,0x0A,0x6D,0xDE,0xB8,0xBE,0xDB,0xCD,0x6A,0x19,0x7E,0x59,0x2D,0x40,0x18,0x89,0x01,0xCE,0xCD,0x65,0x06,0x99,0xC9,0xB5,0xE4,0x56,0xAE,0xA5,0xAD,0xD1,0x90,0x52,0xA8};
 u8 yq3_p521r1[]={0x00,0x6F,0x3B,0x14,0x2E,0xA1,0xBF,0xFF,0x7E,0x28,0x37,0xAD,0x44,0xC9,0xE4,0xFF,0x6D,0x2D,0x34,0xC7,0x31,0x84,0xBB,0xAD,0x90,0x02,0x6D,0xD5,0xE6,0xE8,0x53,0x17,0xD9,0xDF,0x45,0xCA,0xD7,0x80,0x3C,0x6C,0x20,0x03,0x5B,0x2F,0x3F,0xF6,0x3A,0xFF,0x4E,0x1B,0xA6,0x4D,0x1C,0x07,0x75,0x77,0xDA,0x3F,0x42,0x86,0xC5,0x8F,0x0A,0xEA,0xE6,0x43};
   //signature for the message above
 // u8 r3_p521r1[]={0x01,0x54,0xFD,0x38,0x36,0xAF,0x92,0xD0,0xDC,0xA5,0x7D,0xD5,0x34,0x1D,0x30,0x53,0x98,0x85,0x34,0xFD,0xE8,0x31,0x8F,0xC6,0xAA,0xAA,0xB6,0x8E,0x2E,0x6F,0x43,0x39,0xB1,0x9F,0x2F,0x28,0x1A,0x7E,0x0B,0x22,0xC2,0x69,0xD9,0x3C,0xF8,0x79,0x4A,0x92,0x78,0x88,0x0E,0xD7,0xDB,0xB8,0xD9,0x36,0x2C,0xAE,0xAC,0xEE,0x54,0x43,0x20,0x55,0x22,0x51};
 // u8 s3_p521r1[]={0x01,0x77,0x05,0xA7,0x03,0x02,0x90,0xD1,0xCE,0xB6,0x05,0xA9,0xA1,0xBB,0x03,0xFF,0x9C,0xDD,0x52,0x1E,0x87,0xA6,0x96,0xEC,0x92,0x6C,0x8C,0x10,0xC8,0x36,0x2D,0xF4,0x97,0x53,0x67,0x10,0x1F,0x67,0xD1,0xCF,0x9B,0xCC,0xBF,0x2F,0x3D,0x23,0x95,0x34,0xFA,0x50,0x9E,0x70,0xAA,0xC8,0x51,0xAE,0x01,0xAA,0xC6,0x8D,0x62,0xF8,0x66,0x47,0x26,0x60};

 //KAT for BP256R1
 //RFC6932 test vector
 u8 d3_bp256r1[] ={0x04,0x1E,0xB8,0xB1,0xE2,0xBC,0x68,0x1B,0xCE,0x8E,0x39,0x96,0x3B,0x2E,0x9F,0xC4,0x15,0xB0,0x52,0x83,0x31,0x3D,0xD1,0xA8,0xBC,0xC0,0x55,0xF1,0x1A,0xE4,0x96,0x99};
 u8 xq3_bp256r1[]={0x78,0x02,0x84,0x96,0xB5,0xEC,0xAA,0xB3,0xC8,0xB6,0xC1,0x2E,0x45,0xDB,0x1E,0x02,0xC9,0xE4,0xD2,0x6B,0x41,0x13,0xBC,0x4F,0x01,0x5F,0x60,0xC5,0xCC,0xC0,0xD2,0x06};
 u8 yq3_bp256r1[]={0xA2,0xAE,0x17,0x62,0xA3,0x83,0x1C,0x1D,0x20,0xF0,0x3F,0x8D,0x1E,0x3C,0x0C,0x39,0xAF,0xE6,0xF0,0x9B,0x4D,0x44,0xBB,0xE8,0x0C,0xD1,0x00,0x98,0x7B,0x05,0xF9,0x2B};
 // u8 msg3_bp256r1[]={'a','b','c'};
 //u8 r3_bp256r1[]={0x56,0xd4,0xd0,0xd0,0xfa,0x96,0xa9,0x60,0x2b,0x1f,0x05,0xb9,0x06,0x34,0x1c,0x0a,0xfa,0xa2,0x1b,0xaa,0x5e,0xd6,0x8d,0xa7,0x1f,0x08,0xa1,0xcc,0x7b,0x2b,0xe7,0xd9};
//u8 s3_bp256r1[]={0x40,0xa6,0xc8,0x3e,0xed,0x38,0x8e,0x26,0xdf,0xec,0xc5,0x90,0x63,0xed,0x7b,0x59,0xde,0xe1,0x43,0x5d,0x20,0x5a,0x93,0x4d,0x72,0x7f,0xed,0xfc,0x9f,0xa6,0x4f,0x35}; 

 //KAT for BP384R1
 //RFC 6932
 u8 d3_bp384r1[] = {0x01,0x4E,0xC0,0x75,0x5B,0x78,0x59,0x4B,0xA4,0x7F,0xB0,0xA5,0x6F,0x61,0x73,0x04,0x5B,0x43,0x31,0xE7,0x4B,0xA1,0xA6,0xF4,0x73,0x22,0xE7,0x0D,0x79,0xD8,0x28,0xD9,0x7E,0x09,0x58,0x84,0xCA,0x72,0xB7,0x3F,0xDA,0xBD,0x59,0x10,0xDF,0x0F,0xA7,0x6A};
 u8 xq3_bp384r1[] = {0x45,0xCB,0x26,0xE4,0x38,0x4D,0xAF,0x6F,0xB7,0x76,0x88,0x53,0x07,0xB9,0xA3,0x8B,0x7A,0xD1,0xB5,0xC6,0x92,0xE0,0xC3,0x2F,0x01,0x25,0x33,0x27,0x78,0xF3,0xB8,0xD3,0xF5,0x0C,0xA3,0x58,0x09,0x9B,0x30,0xDE,0xB5,0xEE,0x69,0xA9,0x5C,0x05,0x8B,0x4E};
 u8 yq3_bp384r1[] = {0x81,0x73,0xA1,0xC5,0x4A,0xFF,0xA7,0xE7,0x81,0xD0,0xE1,0xE1,0xD1,0x2C,0x0D,0xC2,0xB7,0x4F,0x4D,0xF5,0x8E,0x4A,0x4E,0x3A,0xF7,0x02,0x6C,0x5D,0x32,0xDC,0x53,0x0A,0x2C,0xD8,0x9C,0x85,0x9B,0xB4,0xB4,0xB7,0x68,0x49,0x7F,0x49,0xAB,0x8C,0xC8,0x59};
 // u8 msg3_bp384r1[]={'a','b','c'};
 //u8 r3_bp384r1[]={0x12,0x45,0xdf,0xf5,0x15,0x1f,0xb1,0xed,0x4b,0x99,0xfd,0xef,0xe2,0x48,0x9e,0x16,0xcf,0x70,0x5a,0x2d,0x7e,0xa7,0x7b,0xa8,0xea,0x88,0x2f,0x17,0x8f,0x48,0x9f,0x3d,0x2c,0xa2,0xf4,0xc5,0xc5,0xf5,0xc9,0xde,0x5e,0xd0,0xd5,0x69,0x7e,0x93,0xe8,0xa8};
//u8 s3_bp384r1[]={0x0c,0xf4,0xe5,0x7a,0xe9,0x20,0xbd,0x4f,0x49,0xcb,0xdc,0xf8,0xf0,0xa5,0x33,0xa9,0x47,0x25,0xf5,0x3e,0x26,0x46,0xde,0x45,0xcd,0x91,0x83,0x96,0xe8,0xd3,0xc8,0x9b,0xa9,0x9f,0x39,0xf1,0xdf,0x96,0x5b,0x07,0xd8,0x41,0x0c,0x67,0x91,0xa8,0x38,0xa6};
 
 //KAT for BP512R1
 //RFC 6932
 u8 d3_bp512r1[]={0x63,0x6B,0x6B,0xE0,0x48,0x2A,0x6C,0x1C,0x41,0xAA,0x7A,0xE7,0xB2,0x45,0xE9,0x83,0x39,0x2D,0xB9,0x4C,0xEC,0xEA,0x26,0x60,0xA3,0x79,0xCF,0xE1,0x59,0x55,0x9E,0x35,0x75,0x81,0x82,0x53,0x91,0x17,0x5F,0xC1,0x95,0xD2,0x8B,0xAC,0x0C,0xF0,0x3A,0x78,0x41,0xA3,0x83,0xB9,0x5C,0x26,0x2B,0x98,0x37,0x82,0x87,0x4C,0xCE,0x6F,0xE3,0x33};
 u8 xq3_bp512r1[] ={0x05,0x62,0xE6,0x8B,0x9A,0xF7,0xCB,0xFD,0x55,0x65,0xC6,0xB1,0x68,0x83,0xB7,0x77,0xFF,0x11,0xC1,0x99,0x16,0x1E,0xCC,0x42,0x7A,0x39,0xD1,0x7E,0xC2,0x16,0x64,0x99,0x38,0x95,0x71,0xD6,0xA9,0x94,0x97,0x7C,0x56,0xAD,0x82,0x52,0x65,0x8B,0xA8,0xA1,0xB7,0x2A,0xE4,0x2F,0x4F,0xB7,0x53,0x21,0x51,0xAF,0xC3,0xEF,0x09,0x71,0xCC,0xDA};
 u8 yq3_bp512r1[] ={0xA7,0xCA,0x2D,0x81,0x91,0xE2,0x17,0x76,0xA8,0x98,0x60,0xAF,0xBC,0x1F,0x58,0x2F,0xAA,0x30,0x8D,0x55,0x1C,0x1D,0xC6,0x13,0x3A,0xF9,0xF9,0xC3,0xCA,0xD5,0x99,0x98,0xD7,0x00,0x79,0x54,0x81,0x40,0xB9,0x0B,0x1F,0x31,0x1A,0xFB,0x37,0x8A,0xA8,0x1F,0x51,0xB2,0x75,0xB2,0xBE,0x6B,0x7D,0xEE,0x97,0x8E,0xFC,0x73,0x43,0xEA,0x64,0x2E};
 //u8 msg3_bp512r1[]={'a','b','c'};
//u8 r3_bp512r1[]={0x93,0x0b,0x87,0x41,0x6f,0x43,0x6c,0x5d,0xba,0x06,0xc1,0x63,0x15,0x3e,0x82,0x87,0x59,0xbd,0x4a,0x66,0xc3,0x34,0xe0,0x8d,0x2d,0x66,0x6f,0xe8,0x23,0xb0,0x83,0xad,0xec,0xd6,0xb6,0x15,0xf6,0xfb,0xf0,0xa8,0x50,0xc7,0x3f,0xe3,0xfa,0xbb,0xb2,0xdc,0x9d,0x1a,0xa4,0xc5,0xca,0x53,0x72,0x22,0xb3,0x48,0x2f,0xeb,0xad,0x4b,0xe1,0x34};
//u8 s3_bp512r1[]={0x3e,0x2f,0xcf,0xa1,0x2d,0x1a,0x6e,0xd8,0x08,0x30,0x5b,0xea,0xce,0xd7,0xe7,0xa0,0xbb,0xf8,0x48,0x62,0x5a,0xca,0xfc,0x3b,0x8e,0x15,0x97,0xb4,0xc3,0x2e,0xf2,0x48,0x84,0x90,0x43,0x9b,0x20,0x80,0xe9,0xef,0x7b,0x7d,0xdb,0x22,0xad,0x41,0xbd,0x1e,0x58,0xdb,0xb8,0x4a,0xf1,0xe2,0x29,0xe4,0x16,0xc0,0xd9,0x1e,0x90,0x7a,0xf2,0xa4};

  u8 r[SECP521R1_BYTESIZE];  
  u8 s[SECP521R1_BYTESIZE];
  u8 msg[3]={'a','b','c'};
  u8 tab_curve[MAX_CURVE];
  u8 tab_hash[MAX_HASH_FUNCTIONS];
  int itab_curve,itab_hash;
  u8 *msg3;
  u8 *d3;
  int msg3_len;
  int resu;
  int i,loop;
  int configuration;
  int count;
  int hash;
  int curve;
  ucl_type_ecc_u8_affine_point q3;
  ucl_type_ecdsa_signature signature;
  ucl_type_curve *curve_params;
  int (*hash_function_ptr)(u8*,u8*,u32);

 char curve_name[MAX_CURVE][20];
 char hash_name[MAX_HASH_FUNCTIONS][20];

  sprintf(hash_name[UCL_SHA256],"sha256");
  sprintf(hash_name[UCL_SHA384],"sha384");
  sprintf(hash_name[UCL_SHA512],"sha512");
 
 sprintf(curve_name[SECP192R1],"p192r1");
 sprintf(curve_name[SECP256R1],"p256r1");
 sprintf(curve_name[SECP384R1],"p384r1");
 sprintf(curve_name[SECP521R1],"p521r1");
 sprintf(curve_name[BP256R1],"bp256r1");
 sprintf(curve_name[BP384R1],"bp384r1");
 sprintf(curve_name[BP512R1],"bp512r1");

 
#ifdef VERBOSE
  PRINTF("TEST ECDSA curves\n");
#endif
  tab_curve[4]=SECP192R1;
  tab_curve[1]=SECP256R1;
  tab_curve[2]=SECP384R1;
  tab_curve[3]=SECP521R1;
  tab_curve[0]=BP256R1;
  tab_curve[5]=BP384R1;
  tab_curve[6]=BP512R1;
  tab_hash[0]=UCL_SHA256;
  tab_hash[1]=UCL_SHA384;
  tab_hash[2]=UCL_SHA512;

  for(itab_curve=0;itab_curve<7;itab_curve++)
    for(itab_hash=0;itab_hash<3;itab_hash++)
      {
	curve=tab_curve[itab_curve];
	hash=tab_hash[itab_hash];
#ifdef VERBOSE
	PRINTF("ECDSA-%s-%s TEST START -----\n",curve_name[curve],hash_name[hash]);
#endif
	signature.r=r;
	signature.s=s;
	d3=d3_p192r1;
	curve_params=&secp192r1;
	hash_function_ptr=(&ucl_sha256);
	switch(curve)
	  {
	  case SECP192R1:
	    q3.x=xq3_p192r1;
	    q3.y=yq3_p192r1;
	    d3=d3_p192r1;
	    curve_params=&secp192r1;
	    break;
	  case SECP256R1:
	    q3.x=xq3_p256r1;
	    q3.y=yq3_p256r1;
	    d3=d3_p256r1;
	    curve_params=&secp256r1;
	    break;
	  default:
	    break;
	  case SECP384R1:
	    q3.x=xq3_p384r1;
	    q3.y=yq3_p384r1;
	    d3=d3_p384r1;
	    curve_params=&secp384r1;
	    break;
	  case SECP521R1:
	    q3.x=xq3_p521r1;
	    q3.y=yq3_p521r1;
	    d3=d3_p521r1;
	    curve_params=&secp521r1;
	    break;
	  case BP256R1:
	    q3.x=xq3_bp256r1;
	    q3.y=yq3_bp256r1;
	    d3=d3_bp256r1;
	    curve_params=&bp256r1;
	    break;
	  case BP384R1:
	    q3.x=xq3_bp384r1;
	    q3.y=yq3_bp384r1;
	    d3=d3_bp384r1;
	    curve_params=&bp384r1;
	    break;
	  case BP512R1:
	    q3.x=xq3_bp512r1;
	    q3.y=yq3_bp512r1;
	    d3=d3_bp512r1;
	    curve_params=&bp512r1;
	    break;
	  }
	msg3=msg;
	msg3_len=sizeof(msg);
	switch(hash)
	  {
	  case UCL_SHA256:
	    hash_function_ptr=(&ucl_sha256);
	    break;
	  case UCL_SHA384:
	    hash_function_ptr=(&ucl_sha384);
	    break;
	  case UCL_SHA512:
	    hash_function_ptr=(&ucl_sha512);
	    break;
	  default:
	    break;
	  }
	//loop on sign+verify cycles, with RFC 4754 parameters fixed
	//only the ECDSA random number is changing
	loop=LOOP;
#ifdef VERBOSE
	PRINTF("ECDSA COMPUTATION %s-%s SIGN+VERIFY, loop=%d ",curve_name[curve],hash_name[hash],loop);
#endif
	for(count=0,i=0;i<loop;i++)
	  {
	    //generating a new signature and verifying it
	    configuration=(curve<<UCL_CURVE_SHIFT)^(UCL_MSG_INPUT<<UCL_INPUT_SHIFT)^(hash<<UCL_HASH_SHIFT);
	    resu=ucl_ecdsa_signature(signature,d3,hash_function_ptr,msg3,msg3_len,curve_params,configuration);
#ifdef DISPLAY
		  for(i=0;i<curve_params->curve_bsize;i++)
		    PRINTF("%02x",signature.r[i]);
		  PRINTF("\n");
		  for(i=0;i<curve_params->curve_bsize;i++)
		    PRINTF("%02x",signature.s[i]);
		  PRINTF("\n");
#endif
	    if(UCL_OK!=resu)
	      printf("error signature=%d\n",resu);
	    resu=ucl_ecdsa_verification(q3,signature,hash_function_ptr,msg3,msg3_len,curve_params,configuration);
	    if(resu==UCL_ERROR)
	      {
		PRINTF("ECDSA SIGNATURE TEST-LOOP %s-%s NOK %d \n",curve_name[curve],hash_name[hash],resu);
		return(UCL_ERROR);
	      }
	    else
	      count++;
	  }
#ifdef VERBOSE
	if(loop==count)
	  PRINTF("OK\n");
	else
	  PRINTF("NOK (%d/%d)\n",count,loop);
	PRINTF( "ECDSA %s-%s TEST END -----\n",curve_name[curve],hash_name[hash]);
#endif
      }
  return(UCL_OK);
}
#endif//ECDSA
